/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xmlsec.signature.impl;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.UnmarshallingException;
import org.opensaml.xmlsec.signature.DSAKeyValue;
import org.opensaml.xmlsec.signature.ECKeyValue;
import org.opensaml.xmlsec.signature.KeyValue;
import org.opensaml.xmlsec.signature.RSAKeyValue;

/**
 * A thread-safe Unmarshaller for {@link KeyValue} objects.
 */
public class KeyValueUnmarshaller extends AbstractXMLSignatureUnmarshaller {

    /** {@inheritDoc} */
    protected void processChildElement(XMLObject parentXMLObject, XMLObject childXMLObject)
            throws UnmarshallingException {
        KeyValue keyValue = (KeyValue) parentXMLObject;

        if (childXMLObject instanceof DSAKeyValue) {
            keyValue.setDSAKeyValue((DSAKeyValue) childXMLObject);
        } else if (childXMLObject instanceof RSAKeyValue) {
            keyValue.setRSAKeyValue((RSAKeyValue) childXMLObject);
        } else if (childXMLObject instanceof ECKeyValue) {
            keyValue.setECKeyValue((ECKeyValue) childXMLObject);
        } else {
            // There can be only one...
            if (keyValue.getUnknownXMLObject() == null) {
                keyValue.setUnknownXMLObject(childXMLObject);
            } else {
                // If this happens, throw the others up to the parent class to be logged/handled.
                super.processChildElement(parentXMLObject, childXMLObject);
            }
        }
    }

}